@@ -32,7 +32,7 @@ use Glib::Object::Subclass Gtk3::Dialog::,
     ),
   ];
 
-our $VERSION = '2.5.6';
+our $VERSION = '2.6.1';
 my $EMPTY = q{};
 
 sub INIT_INSTANCE {
@@ -101,7 +101,9 @@ sub add_actions {
     $self->signal_connect(
         response => sub {
             my ( $widget, $response ) = @_;
-            $callbacks{$response}->();
+            if ( defined $response and defined $callbacks{$response} ) {
+                $callbacks{$response}->();
+            }
         }
     );
     return @buttons;
