@@ -288,7 +288,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::, signals => {
     ),
   ];
 
-our $VERSION = '2.5.6';
+our $VERSION = '2.6.1';
 
 my ( $d_sane, $logger );
 my $SANE_NAME_SCAN_TL_X   = SANE_NAME_SCAN_TL_X;
@@ -811,10 +811,15 @@ sub _edit_profile_callback {
 sub _build_profile_table {
     my ( $profile, $options, $vbox ) = @_;
 
+    my $frameb = Gtk3::Frame->new( __('Backend options') );
+    my $framef = Gtk3::Frame->new( __('Frontend options') );
+    $vbox->pack_start( $frameb, TRUE, TRUE, 0 );
+    $vbox->pack_start( $framef, TRUE, TRUE, 0 );
+
     # listbox to align widgets
     my $listbox = Gtk3::ListBox->new;
     $listbox->set_selection_mode('none');
-    $vbox->pack_start( $listbox, TRUE, TRUE, 0 );
+    $frameb->add($listbox);
     my $iter = $profile->each_backend_option;
     while ( my $i = $iter->() ) {
         my ( $name, $val ) = $profile->get_backend_option_by_index($i);
@@ -829,13 +834,39 @@ sub _build_profile_table {
             clicked => sub {
                 $logger->debug("removing option '$name' from profile");
                 $profile->remove_backend_option_by_index($i);
-                $listbox->destroy;
+                $frameb->destroy;
+                $framef->destroy;
                 _build_profile_table( $profile, $options, $vbox );
             }
         );
         $row->add($hbox);
         $listbox->add($row);
     }
+
+    $listbox = Gtk3::ListBox->new;
+    $listbox->set_selection_mode('none');
+    $framef->add($listbox);
+    $iter = $profile->each_frontend_option;
+    while ( my $name = $iter->() ) {
+        my $row   = Gtk3::ListBoxRow->new;
+        my $hbox  = Gtk3::HBox->new;
+        my $label = Gtk3::Label->new($name);
+        $hbox->pack_start( $label, FALSE, TRUE, 0 );
+        my $button = Gtk3::Button->new_from_stock('gtk-delete');
+        $hbox->pack_end( $button, FALSE, FALSE, 0 );
+        $button->signal_connect(
+            clicked => sub {
+                $logger->debug("removing option '$name' from profile");
+                $profile->remove_frontend_option($name);
+                $frameb->destroy;
+                $framef->destroy;
+                _build_profile_table( $profile, $options, $vbox );
+            }
+        );
+        $row->add($hbox);
+        $listbox->add($row);
+    }
+
     $vbox->show_all;
     return;
 }
@@ -2277,6 +2308,10 @@ sub set_current_scan_options {
         return;
     }
 
+    # forget the previous option info calls, as these are only interesting
+    # *whilst* setting a profile, and now we are starting from scratch
+    delete $self->{option_info};
+
     # If we have no options set, no need to reset to defaults
     if ( $self->{current_scan_options}->num_backend_options == 0 ) {
         $self->add_current_scan_options($profile);
@@ -2314,10 +2349,6 @@ sub add_current_scan_options {
     # First clone the profile, as otherwise it would be self-modifying
     my $clone = dclone($profile);
 
-    # forget the previous option info calls, as these are only interesting
-    # *whilst* setting a profile, and now we are starting from scratch
-    delete $self->{option_info};
-
     push @{ $self->{setting_current_scan_options} }, $clone->{uuid};
 
     # Give the GUI a chance to catch up between settings,
@@ -2545,27 +2576,15 @@ sub update_start_page {
     if ( not defined $start ) { $start = $self->get('page-number-start') }
     my $step = $value - $start;
     if ( $step == 0 ) { $step = $self->get('page-number-increment') }
-    my $exists = TRUE;
-    my $i = $step > 0 ? 0 : $#{ $slist->{data} };
     $start = $value;
 
-    while ($exists) {
-        if (   $i < 0
-            or $i > $#{ $slist->{data} }
-            or ( $slist->{data}[$i][0] > $value and $step > 0 )
-            or ( $slist->{data}[$i][0] < $value and $step < 0 ) )
-        {
-            $exists = FALSE;
-        }
-        elsif ( $slist->{data}[$i][0] == $value ) {
-            $value += $step;
-            if ( $value < 1 ) {
-                $value = 1;
-                $step  = 1;
-            }
+    while ( $slist->pages_possible( $value, $step ) == 0 ) {
+        if ( $value < 1 ) {
+            $value = 1;
+            $step  = 1;
         }
         else {
-            $i += $step > 0 ? 1 : $NO_INDEX;
+            $value += $step;
         }
     }
     $self->set( 'page-number-start', $value );
@@ -2610,6 +2629,18 @@ sub set_cursor {
     return;
 }
 
+sub get_label_for_option {
+    my ( $self, $name ) = @_;
+    my $widget = $self->{option_widgets}{$name};
+    my $hbox   = $widget->get_parent;
+    for my $child ( $hbox->get_children ) {
+        if ( $child->isa('Gtk3::Label') ) {
+            return $child->get_text;
+        }
+    }
+    return;
+}
+
 1;
 
 __END__
