@@ -81,7 +81,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::Scan::, signals => {
     ),
   ];
 
-our $VERSION = '2.5.6';
+our $VERSION = '2.6.1';
 
 my $SANE_NAME_PAGE_HEIGHT = SANE_NAME_PAGE_HEIGHT;
 my $SANE_NAME_PAGE_WIDTH  = SANE_NAME_PAGE_WIDTH;
@@ -389,7 +389,11 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
 
             # Label
             if ( $opt->{type} != SANE_TYPE_BUTTON ) {
-                my $label = Gtk3::Label->new( $d_sane->get( $opt->{title} ) );
+                my $text = $opt->{title};
+                if ( not defined $text or $text eq $EMPTY ) {
+                    $text = $opt->{name};
+                }
+                my $label = Gtk3::Label->new( $d_sane->get($text) );
                 $hbox->pack_start( $label, FALSE, FALSE, 0 );
             }
 
