@@ -16,7 +16,7 @@ Readonly my $EMPTY_ARRAY => -1;
 # Glib::ParamSpec->object in Gscan2pdf::Dialog::Scan
 use Glib::Object::Subclass Glib::Object::;
 
-our $VERSION = '2.5.6';
+our $VERSION = '2.6.1';
 
 my $units = qr{(pel|bit|mm|dpi|%|us)}xsm;
 my $EMPTY = q{};
@@ -227,7 +227,7 @@ sub flatbed_selected {
     my ($self) = @_;
     return (
         defined $self->{source} and ( defined $self->{source}{val}
-            and $self->{source}{val} =~ /flatbed/xsmi )
+            and $self->{source}{val} =~ /(flatbed|Document[ ]Table)/xsmi )
           or (  $#{ $self->{source}{constraint} } == 0
             and $self->{source}{constraint}[0] =~ /flatbed/xsmi )
     );
